# Generated by Django 2.2.2 on 2019-06-05 12:39

from django.db import migrations, models
import django.db.models.deletion
import django_countries.fields
import localflavor.generic.models
import shark.sepa.models


class Migration(migrations.Migration):

    dependencies = [
        ('sepa', '0005_change_due_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='directdebitbatch',
            name='creditor_iban',
            field=localflavor.generic.models.IBANField(default=shark.sepa.models.get_default_creditor_iban, include_countries=None, max_length=34, use_nordea_extensions=False, verbose_name='creditor IBAN'),
        ),
        migrations.AlterField(
            model_name='directdebitbatch',
            name='mandate_type',
            field=models.CharField(choices=[('CORE', 'CORE'), ('COR1', 'COR1'), ('B2B', 'B2B')], max_length=4, verbose_name='mandate type'),
        ),
        migrations.AlterField(
            model_name='directdebitbatch',
            name='sequence_type',
            field=models.CharField(choices=[('FRST', 'FRST'), ('RCUR', 'RCUR')], max_length=4, verbose_name='sequence type'),
        ),
        migrations.AlterField(
            model_name='directdebitmandate',
            name='bic',
            field=localflavor.generic.models.BICField(help_text='Bank Identifier Code', max_length=11, verbose_name='BIC'),
        ),
        migrations.AlterField(
            model_name='directdebitmandate',
            name='country',
            field=django_countries.fields.CountryField(default='DE', max_length=2),
        ),
        migrations.AlterField(
            model_name='directdebitmandate',
            name='iban',
            field=localflavor.generic.models.IBANField(help_text='International Bank Account Number', include_countries=None, max_length=34, use_nordea_extensions=False, verbose_name='IBAN'),
        ),
        migrations.AlterField(
            model_name='directdebitmandate',
            name='type',
            field=models.CharField(choices=[('CORE', 'CORE'), ('COR1', 'COR1'), ('B2B', 'B2B')], max_length=4),
        ),
        migrations.AlterField(
            model_name='directdebittransaction',
            name='mandate',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='sepa.DirectDebitMandate', verbose_name='SEPA DD mandate'),
        ),
    ]
