# Generated by Django 2.2.2 on 2019-06-05 15:21

from django.db import migrations, models
import shark.utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('customer', '0006_add_address_addition_2'),
    ]

    operations = [
        migrations.AddField(
            model_name='customeraddress',
            name='state',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AlterField(
            model_name='customer',
            name='address',
            field=shark.utils.fields.OldAddressField(blank=True, verbose_name='address'),
        ),
        migrations.AlterField(
            model_name='customeraddress',
            name='address_addition_1',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (1st row)'),
        ),
        migrations.AlterField(
            model_name='customeraddress',
            name='address_addition_2',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (2nd row)'),
        ),
    ]
