# Generated by Django 2.2.2 on 2019-06-05 13:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('customer', '0004_add_various_fields'),
    ]

    operations = [
        migrations.AddField(
            model_name='customercontact',
            name='customer',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='customer.Customer'),
            preserve_default=False,
        ),
    ]
