# Generated by Django 2.2.2 on 2019-06-05 15:21

from django.db import migrations, models
import django_countries.fields


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0004_improve_document'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='document',
            name='recipient',
        ),
        migrations.RemoveField(
            model_name='document',
            name='sender',
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_address_addition_1',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (1st row)'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_address_addition_2',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (2nd row)'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_city',
            field=models.CharField(blank=True, max_length=100, verbose_name='city'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_country',
            field=django_countries.fields.CountryField(blank=True, max_length=2, verbose_name='country'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_name',
            field=models.CharField(blank=True, max_length=100, verbose_name='name'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_postal_code',
            field=models.CharField(blank=True, max_length=10, verbose_name='postal code'),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_state',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='document',
            name='recipient_street',
            field=models.CharField(blank=True, max_length=100, verbose_name='street'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_address_addition_1',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (1st row)'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_address_addition_2',
            field=models.CharField(blank=True, max_length=100, verbose_name='address addition (2nd row)'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_city',
            field=models.CharField(blank=True, max_length=100, verbose_name='city'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_country',
            field=django_countries.fields.CountryField(blank=True, max_length=2, verbose_name='country'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_name',
            field=models.CharField(blank=True, max_length=100, verbose_name='name'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_postal_code',
            field=models.CharField(blank=True, max_length=10, verbose_name='postal code'),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_state',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AddField(
            model_name='document',
            name='sender_street',
            field=models.CharField(blank=True, max_length=100, verbose_name='street'),
        ),
    ]
