# Generated by Django 2.2.2 on 2019-06-05 12:51

from decimal import Decimal
from django.db import migrations, models
import shark.billing.models
import shark.utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('billing', '0002_add_item_type_and_payment_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invoice',
            name='payment_type',
            field=models.CharField(choices=[('invoice', 'Invoice'), ('direct_debit', 'Direct debit')], default='invoice', help_text="Will be copied from customer's preferences automatically.", max_length=20, verbose_name='Payment Type'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='sender',
            field=shark.utils.fields.OldAddressField(blank=True, default='Awesome Corp\nGreatstreet 123\n12345 Nicertown'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='type',
            field=models.CharField(choices=[('invoice', 'Invoice'), ('correction', 'Correction of invoice')], default='invoice', max_length=20, verbose_name='type'),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='discount',
            field=models.DecimalField(decimal_places=2, default=Decimal('0.00'), max_digits=3, verbose_name='discount'),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='type',
            field=models.CharField(choices=[('item', 'Item'), ('title', 'Title')], default='item', max_length=10),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='unit',
            field=shark.billing.models.UnitField(blank=True, max_length=10, verbose_name='unit'),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='vat_rate',
            field=shark.billing.models.VatRateField(decimal_places=2, max_digits=3, verbose_name='VAT rate'),
        ),
    ]
