# Generated by Django 2.2.2 on 2019-06-05 12:39

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import shark.customer.models
import shark.utils.fields
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('customer', '0003_extra_fields_and_customer_address'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='name',
            field=models.CharField(blank=True, max_length=50),
        ),
        migrations.AddField(
            model_name='customer',
            name='primary_admin',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='customer',
            name='type',
            field=shark.customer.models.CustomerTypeField(db_index=True, max_length=20),
        ),
        migrations.AddField(
            model_name='customeraddress',
            name='sender_line',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AddField(
            model_name='customercomment',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='customercontact',
            name='email',
            field=models.EmailField(blank=True, max_length=254),
        ),
        migrations.AlterField(
            model_name='customer',
            name='invoice_dispatch_type',
            field=models.CharField(choices=[('email', 'via email'), ('fax', 'via FAX'), ('mail', 'via mail')], default='email', max_length=20, verbose_name='Invoice dispatch type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='language',
            field=shark.utils.fields.LanguageField(blank=True, max_length=5, verbose_name='language'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='payment_type',
            field=models.CharField(choices=[('invoice', 'Invoice'), ('direct_debit', 'Direct debit')], default='invoice', max_length=20, verbose_name='Payment Type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='tags',
            field=taggit.managers.TaggableManager(blank=True, help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AlterField(
            model_name='customercontact',
            name='gender',
            field=models.CharField(blank=True, choices=[('M', 'Male'), ('F', 'Female')], max_length=1, verbose_name='Gender'),
        ),
        migrations.AlterField(
            model_name='customercontact',
            name='title',
            field=models.CharField(blank=True, choices=[('Herr', 'Herr'), ('Frau', 'Frau'), ('Fräulein', 'Fräulein'), ('Dr.', 'Dr.'), ('Dr. Dr.', 'Dr. Dr.'), ('Prof. Dr.', 'Prof. Dr.')], help_text='z.B. Herr, Frau, Dr., Prof.,...', max_length=20, verbose_name='Salutation'),
        ),
    ]
