# Generated by Django 2.2.2 on 2019-06-05 14:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customer', '0005_customercontact_customer'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customeraddress',
            old_name='address_addition',
            new_name='address_addition_1'
        ),
        migrations.AlterField(
            model_name='customeraddress',
            name='address_addition_1',
            field=models.CharField(default='', max_length=100, verbose_name='address addition (1st row)'),
        ),
        migrations.AddField(
            model_name='customeraddress',
            name='address_addition_2',
            field=models.CharField(default='', max_length=100, verbose_name='address addition (2nd row)'),
            preserve_default=False,
        ),
    ]
