# Generated by Django 2.2.2 on 2019-06-05 12:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('issue', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(upload_to='issue/attachment', verbose_name='file'),
        ),
        migrations.AlterField(
            model_name='relation',
            name='type',
            field=models.CharField(choices=[('parent', 'parent'), ('related', 'related'), ('duplicate', 'duplicate')], max_length=10, verbose_name='type'),
        ),
    ]
