# Generated by Django 2.1.1 on 2018-09-10 17:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0002_meta_changes'),
    ]

    operations = [
        migrations.AddField(
            model_name='document',
            name='thumbnail_large',
            field=models.ImageField(default='', editable=False, upload_to='documents'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='document',
            name='thumbnail_medium',
            field=models.ImageField(default='', editable=False, upload_to='documents'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='document',
            name='thumbnail_small',
            field=models.ImageField(default='', editable=False, upload_to='documents'),
            preserve_default=False,
        ),
    ]
