# Generated by Django 2.2.2 on 2019-06-05 12:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('banking', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='currency',
            field=models.CharField(default='EUR', max_length=3),
        ),
    ]
